@@ -296,6 +296,11 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
 					      NAUTILUS_ICON_SIZE_SMALLER);
 	
 	rend = gtk_cell_renderer_text_new ();
+	g_object_set (rend,
+		      "ellipsize", PANGO_ELLIPSIZE_END,
+		      "ellipsize-set", TRUE,
+		      NULL);
+
 	col = gtk_tree_view_column_new_with_attributes ("Icon", 
 							rend,
 							"text", 
@@ -499,7 +504,7 @@ nautilus_bookmarks_window_save_geometry (GtkWindow *window)
 	g_return_if_fail (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
 
 	/* Don't bother if window is already closed */
-	if (GTK_WIDGET_VISIBLE (window)) {
+	if (gtk_widget_get_visible (GTK_WIDGET (window))) {
 		char *geometry_string;
 		
 		geometry_string = eel_gtk_window_get_geometry_string (window);
@@ -814,11 +819,15 @@ update_bookmark_from_text (void)
 		g_assert (GTK_IS_ENTRY (name_field));
 		g_assert (GTK_IS_ENTRY (uri_field));
 
+		if (gtk_entry_get_text_length (GTK_ENTRY (uri_field)) == 0) {
+			return;
+		}
+
 		location = g_file_parse_name 
 			(gtk_entry_get_text (GTK_ENTRY (uri_field)));
 		
-		bookmark = nautilus_bookmark_new_with_icon (location, gtk_entry_get_text (GTK_ENTRY (name_field)),
-							    name_text_changed, NULL);
+		bookmark = nautilus_bookmark_new (location, gtk_entry_get_text (GTK_ENTRY (name_field)),
+		                                  name_text_changed, NULL);
 		
 		g_object_unref (location);
 
